@@ -255,6 +255,7 @@ def matplotlib_bar(args, values="R-values", flag_sets=[], ready_shells=[]):
         # https://github.com/matplotlib/matplotlib/issues/5209
         warnings.simplefilter(action='ignore', category=FutureWarning)
         plt.savefig(pngfilename, bbox_inches="tight", dpi=96)
+        # plt.savefig(pngfilename + ".eps", bbox_inches="tight", format="eps")
     plt.clf()
     plt.close('all')
     return pngfilename
@@ -500,7 +501,7 @@ def matplotlib_line(shells, project, statistics, n_bins_low, title, flag=0,
         for i, statistic in enumerate(statistics):
             if statistic == "CC*" and os.path.isfile(csvfilename):
                 values_label = r'CC$^*$'
-                values_column = 14
+                values_column = -1
                 marker = "*"
                 color = "g"
                 linestyle = '--'
@@ -545,7 +546,7 @@ def matplotlib_line(shells, project, statistics, n_bins_low, title, flag=0,
                     values_column = 11
                 elif statistic == "CChalf" and os.path.isfile(csvfilename):
                     values_label = r'CC$_\mathrm{1/2}$'
-                    values_column = 12
+                    values_column = -2
                 else:
                     break
             values_list = []
@@ -583,6 +584,7 @@ def matplotlib_line(shells, project, statistics, n_bins_low, title, flag=0,
     plt.setp(ax.get_xticklabels(), horizontalalignment='center',
              rotation=xticklabels_rotation)
     plt.savefig(pngfilename, bbox_inches="tight", dpi=dpi)
+    # plt.savefig(pngfilename + ".eps", bbox_inches="tight", format="eps")
     plt.clf()
     plt.close('all')
     return pngfilename
