@@ -756,7 +756,7 @@ def calculate_merging_stats(hklin_unmerged, shells, project, bins_low,
     with open(csvfilename, "w") as csvfile:
         csvfile.writelines("#shell d_max  d_min   #obs  #uniq   mult.  %comp"
                            "       <I>  <I/sI>    r_mrg   r_meas    r_pim   "
-                           "cc1/2   cc_ano     cc* \n")
+                           "r_anom   cc1/2   cc_ano     cc* \n")
 
     ## Collect statistics, calculate CC*-values and save them to CSV file
 
@@ -774,7 +774,7 @@ def calculate_merging_stats(hklin_unmerged, shells, project, bins_low,
         """
         for i in range(len(lines)):
             # Compute CC*
-            bin_CChalf = lines[i].split()[11]
+            bin_CChalf = lines[i].split()[-2]
             if bin_CChalf < 0:
                 bin_CCstar = "N/A"
                 warning_my("CC*", "A CC*-value for a particular shell "
